{*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Angular Notch Filter","$schema":"http://json-schema.org/draf'
      + 't-04/schema#","type":"object","properties":{"angle":{"description":"An'
      + 'gle [deg]","items":{"type":"number"},"type":"array"},"amplitude_mean":'
      + '{"description":"Mean amplitude [dB]","items":{"type":"number"},"type":'
      + '"array"},"range_mean":{"description":"Mean range [m]","items":{"type":'
      + '"number"},"type":"array"}},"required":["angle","range_mean","amplitude'
      + '_mean"],"description":"Angular notch filter parameters for window '
      + 'glass echoes"}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"amp'
      + 'litude_mean":[3.780913,3.780913,3.480913,3.120913,2.850913,2.720913,2.'
      + '680913,2.610913,2.530913,2.570913,2.570913],"range_mean":[0.094,0.094,'
      + '0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Atmospheric Parameters","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","properties":{"temperature":{"descript'
      + 'ion":"Temperature along measurement path '
      + '[\u00b0C]","type":"number"},"wavelength":{"description":"Laser '
      + 'wavelength [nm]","type":"number"},"pressure":{"description":"Pressure '
      + 'along measurment path '
      + '[mbar]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"amsl":{"description":"Height above mean sea '
      + 'level (AMSL) '
      + '[m]","type":"number"},"attenuation":{"description":"Atmospheric '
      + 'attenuation '
      + '[1/km]","type":"number"},"group_velocity":{"description":"Group '
      + 'velocity of laser beam [m/s]","type":"number"}},"required":["temperatu'
      + 're","pressure","rel_humidity","pressure_sl","amsl","group_velocity","a'
      + 'ttenuation","wavelength"],"description":"Atmospheric parameters"}'
    );

    Example : (''
      + '{"temperature":7,"wavelength":1550,"pressure":970,"pressure_sl":970,"r'
      + 'el_humidity":63,"amsl":0,"attenuation":0.028125,"group_velocity":29971'
      + '1000.0}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Beam Geometry","$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#","type":"object","properties":{"beam_exit_diameter":{"exclusiveM'
      + 'inimum":false,"type":"number","minimum":0,"description":"Beam width at'
      + ' exit aperture [m]"},"beam_divergence":{"exclusiveMinimum":false,"type'
      + '":"number","minimum":0,"description":"Beam divergence in far field [ra'
      + 'd]"}},"required":["beam_exit_diameter","beam_divergence"],"description'
      + '":"Laser beam geometry details"}'
    );

    Example : (''
      + '{"beam_exit_diameter":0.0072,"beam_divergence":0.0003}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Control Object Catalog","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","description":"List of control object type definitions'
      + '","properties":{"types":{"uniqueItems":true,"items":{"oneOf":[{"$ref":'
      + '"#/definitions/rectangle"},{"$ref":"#/definitions/checkerboard2x2"},{"'
      + '$ref":"#/definitions/chevron"},{"$ref":"#/definitions/circular_disk"},'
      + '{"$ref":"#/definitions/cylinder"},{"$ref":"#/definitions/sphere"},{"$r'
      + 'ef":"#/definitions/round_corner_cube_prism"}],"type":"object"},"type":'
      + '"array"}},"definitions":{"circular_disk":{"allOf":[{"$ref":"#/definiti'
      + 'ons/common"},{"type":"object","properties":{"shape":{"enum":["circular'
      + '_disk"],"type":"string","description":"shape '
      + 'identifier"},"offset":{"type":"number","description":"offset in '
      + 'meters, e.g. reflector constant (optional)"},"diameter":{"exclusiveMin'
      + 'imum":true,"type":"number","minimum":0,"description":"diameter in '
      + 'meters"}},"required":["shape","diameter"],"description":"circular disk'
      + ' specific properties"}],"type":"object","description":"circular disk"}'
      + ',"sphere":{"allOf":[{"$ref":"#/definitions/common"},{"type":"object","'
      + 'properties":{"shape":{"enum":["sphere"],"type":"string","description":'
      + '"shape identifier"},"diameter":{"exclusiveMinimum":true,"type":"number'
      + '","minimum":0,"description":"diameter in '
      + 'meters"}},"required":["shape","diameter"],"description":"sphere '
      + 'specific properties"}],"type":"object","description":"sphere"},"round_'
      + 'corner_cube_prism":{"allOf":[{"$ref":"#/definitions/common"},{"type":"'
      + 'object","properties":{"shape":{"enum":["round_corner_cube_prism"],"typ'
      + 'e":"string","description":"shape '
      + 'identifier"},"offset":{"type":"number","description":"offset in '
      + 'meters, e.g. reflector constant (optional)"},"diameter":{"exclusiveMin'
      + 'imum":true,"type":"number","minimum":0,"description":"diameter in '
      + 'meters"}},"required":["shape","diameter"],"description":"round corner '
      + 'cube prism specific properties"}],"type":"object","description":"round'
      + ' corner cube prism"},"rectangle":{"allOf":[{"$ref":"#/definitions/comm'
      + 'on"},{"type":"object","properties":{"shape":{"enum":["rectangle"],"typ'
      + 'e":"string"},"width":{"exclusiveMinimum":true,"type":"number","minimum'
      + '":0,"description":"width in meters"},"length":{"exclusiveMinimum":true'
      + ',"type":"number","minimum":0,"description":"length in meters"}},"requi'
      + 'red":["shape","length","width"],"description":"rectangle specific prop'
      + 'erties"}],"type":"object","description":"rectangle"},"common":{"type":'
      + '"object","properties":{"name":{"type":"string","minLength":3,"descript'
      + 'ion":"unique type identifier"},"shape":{"enum":["rectangle","checkerbo'
      + 'ard2x2","chevron","circular_disk","cylinder","sphere","round_corner_cu'
      + 'be_prism"],"type":"string","description":"shape identifier"},"surface_'
      + 'type":{"enum":["retro_reflective_foil","diffuse"],"type":"string","des'
      + 'cription":"surface material '
      + 'type"},"description":{"type":"string","description":"string describing'
      + ' the object"}},"required":["name","shape"],"description":"common '
      + 'object properties"},"chevron":{"allOf":[{"$ref":"#/definitions/common"'
      + '},{"type":"object","properties":{"shape":{"enum":["chevron"],"type":"s'
      + 'tring","description":"shape identifier"},"thickness":{"exclusiveMinimu'
      + 'm":true,"type":"number","minimum":0,"description":"thickness in meters'
      + '"},"outside_edge_length":{"exclusiveMinimum":true,"type":"number","min'
      + 'imum":0,"description":"length of the two outer edges in meters"}},"req'
      + 'uired":["shape","outside_edge_length","thickness"],"description":"chev'
      + 'ron specific properties"}],"type":"object","description":"chevron"},"c'
      + 'ylinder":{"allOf":[{"$ref":"#/definitions/common"},{"type":"object","p'
      + 'roperties":{"shape":{"enum":["cylinder"],"type":"string","description"'
      + ':"shape identifier"},"diameter":{"exclusiveMinimum":true,"type":"numbe'
      + 'r","minimum":0,"description":"diameter in meters"},"height":{"exclusiv'
      + 'eMinimum":true,"type":"number","minimum":0,"description":"height in me'
      + 'ters"}},"required":["shape","diameter","height"],"description":"cylind'
      + 'er specific properties"}],"type":"object","description":"cylinder"},"c'
      + 'heckerboard2x2":{"allOf":[{"$ref":"#/definitions/common"},{"type":"obj'
      + 'ect","properties":{"shape":{"enum":["checkerboard2x2"],"type":"string"'
      + ',"description":"shape identifier"},"square_length":{"exclusiveMinimum"'
      + ':true,"type":"number","minimum":0,"description":"length of a square of'
      + ' the checkerboard in meters"}},"required":["shape","square_length"],"d'
      + 'escription":"checkerboard specific '
      + 'properties"}],"type":"object","description":"checkerboard 2 by '
      + '2"}},"required":["types"],"type":"object"}'
    );

    Example : (''
      + '{"types":[{"name":"Rectangle 60x30","shape":"rectangle","length":0.6,"'
      + 'width":0.3,"description":"Rectangle (60cm x 30cm)"},{"name":"Rectangle'
      + ' 80x40","shape":"rectangle","length":0.8,"width":0.4,"description":"Re'
      + 'ctangle (80cm x 40cm)"},{"name":"Checkerboard2x2 30","shape":"checkerb'
      + 'oard2x2","square_length":0.3,"description":"Checkerboard (square '
      + 'length: 30cm)"},{"name":"Checkerboard2x2 50","shape":"checkerboard2x2"'
      + ',"square_length":0.5,"description":"Checkerboard (square length: '
      + '50cm)"},{"name":"Chevron 24''''/4''''","shape":"chevron","thickness":0.101'
      + '6,"outside_edge_length":0.6096,"description":"Chevron (a=24''''; '
      + 'b=4'''')"},{"name":"Circular Disk 50","shape":"circular_disk","surface_t'
      + 'ype":"diffuse","diameter":0.5,"description":" Circular Disk (diameter:'
      + ' 50cm)"},{"diameter":0.05,"name":"RIEGL flat reflector 50 mm","shape":'
      + '"circular_disk","offset":0.0,"surface_type":"retro_reflective_foil","d'
      + 'escription":"flat circular reflector from retro-reflective '
      + 'foil"},{"diameter":0.1,"name":"RIEGL flat reflector 100 mm","shape":"c'
      + 'ircular_disk","offset":0.0,"surface_type":"retro_reflective_foil","des'
      + 'cription":"flat circular reflector from retro-reflective '
      + 'foil"},{"diameter":0.15,"name":"RIEGL flat reflector 150 mm","shape":"'
      + 'circular_disk","offset":0.0,"surface_type":"retro_reflective_foil","de'
      + 'scription":"flat circular reflector from retro-reflective '
      + 'foil"},{"diameter":0.05,"name":"RIEGL cylindrical reflector 50 '
      + 'mm","shape":"cylinder","description":"cylindrical reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","height"'
      + ':0.05},{"diameter":0.1,"name":"RIEGL cylindrical reflector 100 '
      + 'mm","shape":"cylinder","description":"cylindrical reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","height"'
      + ':0.1},{"name":"Sphere 200 '
      + 'mm","shape":"sphere","diameter":0.2,"description":"Sphere (diameter: '
      + '200 mm)"},{"name":"Corner Cube Prism 50 mm","shape":"round_corner_cube'
      + '_prism","offset":0.0,"diameter":0.05,"description":"round corner cube '
      + 'prism"}],"comments":["This file contains a list of control object '
      + 'types (aka. ''catalog'').","Each type is described by an object,","which'
      + ' must contain at least the following parameters:","  - name: unique '
      + 'identifier of the type","  - shape: one of the following supported '
      + 'shapes:","      - rectangle","      - checkerboard2x2","      - '
      + 'chevron","      - circular_disk","      - cylinder","      - sphere","'
      + '      - round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"reference_file":{"description":"Reference to a control'
      + ' object file","properties":{"file_uuid":{"type":"string","description"'
      + ':"Control object file''s Universally Unique Identifier (RFC '
      + '4122)"},"file_path":{"type":"string","description":"Path of the '
      + 'control object file relative to referring file"}},"required":["file_uu'
      + 'id","file_path"],"type":"object"}},"description":"Details about the '
      + 'control object reference file","$schema":"http://json-schema.org/draft'
      + '-04/schema#","type":"object","title":"Control Object Reference file"}'
    );

    Example : (''
      + '{"reference_file":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213",'
      + '"file_path":"../../../10_CONTROL_OBJECTS/ControlPoints.cpx"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Detection Probability","$schema":"http://json-schema.org/dra'
      + 'ft-04/schema#","type":"object","properties":{"detection_probability":{'
      + '"description":"Detection probability [0..1]","items":{"type":"number"}'
      + ',"type":"array"},"amplitude":{"description":"Amplitude [dB]","items":{'
      + '"type":"number"},"type":"array"}},"required":["amplitude","detection_p'
      + 'robability"],"description":"Detection probability as a function of '
      + 'amplitude"}'
    );

    Example : (''
      + '{"detection_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]'
      + ',"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Information","$schema":"http://json-schema.org/draft-'
      + '04/schema#","type":"object","properties":{"device_name":{"type":"strin'
      + 'g","description":"Optional device name (e.g. ''Scanner 1'' for '
      + 'multi-scanner '
      + 'systems)"},"device_type":{"type":"string","description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)"},"device_build":{"type":"string","description":"Device build'
      + ' variant"},"channel_text":{"type":"string","description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)"},"serial_number":{"type":"string","description":"Device '
      + 'serial number (e.g. S2221234)"},"channel_number":{"exclusiveMinimum":f'
      + 'alse,"type":"integer","minimum":0,"description":"Laser channel number '
      + '(not defined or 0: single channel device)"}},"required":["device_type"'
      + ',"serial_number"],"description":"Details about the device used to '
      + 'acquire the point cloud"}'
    );

    Example : (''
      + '{"device_name":"Scanner 1","device_type":"VZ-400i","device_build":"","'
      + 'channel_text":"","serial_number":"S2221234","channel_number":0}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry","$schema":"http://json-schema.org/draft-04/'
      + 'schema#","type":"object","properties":{"secondary":{"type":"object","p'
      + 'roperties":{"content":{"type":"array","items":{"type":"number"},"descr'
      + 'iption":"Internal calibration values"},"ID":{"maxItems":2,"type":"arra'
      + 'y","minItems":2,"items":{"type":"integer"},"description":"Structure '
      + 'identifier"}},"required":["ID","content"],"description":"Additional '
      + 'device geometry structure (optional)"},"primary":{"type":"object","pro'
      + 'perties":{"content":{"type":"array","items":{"type":"number"},"descrip'
      + 'tion":"Internal calibration values"},"ID":{"maxItems":2,"type":"array"'
      + ',"minItems":2,"items":{"type":"integer"},"description":"Structure '
      + 'identifier"}},"required":["ID","content"],"description":"Primary '
      + 'device geometry structure (mandatory)"},"amu":{"type":"object","proper'
      + 'ties":{"lineCC":{"exclusiveMinimum":false,"type":"number","minimum":0,'
      + '"description":"Line Circle Count (number of LSBs per full rotation '
      + 'about line axis)"},"frameCC":{"exclusiveMinimum":false,"type":"number"'
      + ',"minimum":0,"description":"Frame Circle Count (number of LSBs per '
      + 'full rotation about frame axis)"}},"description":"Angle Measurement '
      + 'Unit"}},"required":["primary"],"description":"Scanner device geometry '
      + 'details"}'
    );

    Example : (''
      + '{"secondary":{"content":[0],"ID":[91,0]},"primary":{"content":[0],"ID"'
      + ':[4,0]},"amu":{"lineCC":124000,"frameCC":124000}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Device Geometry Passive Channel","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","type":"object","properties":{"primary":{"typ'
      + 'e":"object","properties":{"content":{"type":"array","items":{"type":"n'
      + 'umber"},"description":"Internal calibration values"},"ID":{"maxItems":'
      + '2,"type":"array","minItems":2,"items":{"type":"integer"},"description"'
      + ':"Structure '
      + 'identifier"}},"required":["ID","content"],"description":"Primary '
      + 'device geometry structure '
      + '(mandatory)"}},"required":["primary"],"description":"Scanner passive '
      + 'channel device geometry details"}'
    );

    Example : (''
      + '{"primary":{"content":[0],"ID":[143,0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"deviation_minimum":{"description":"Minimum possible '
      + 'pulse shape deviation.","type":"number"},"background_radiation_minimum'
      + '":{"description":"Minimum possible background radiation.","type":"numb'
      + 'er"},"amplitude_maximum":{"description":"Maximum possible amplitude in'
      + ' '
      + 'dB.","type":"number"},"mta_zone_count_maximum":{"description":"Maximum'
      + ' number of MTA '
      + 'zones.","type":"number"},"range_maximum":{"description":"Maximum '
      + 'possible range in '
      + 'meters.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape deviation.","type":"number"},"reflectance_minimum'
      + '":{"description":"Minimum possible reflectance in dB.","type":"number"'
      + '},"background_radiation_maximum":{"description":"Maximum possible '
      + 'background '
      + 'radiation.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in '
      + 'meters.","type":"number"},"echo_count_maximum":{"description":"Maximum'
      + ' number of echoes a laser shot can '
      + 'have.","type":"number"},"reflectance_maximum":{"description":"Maximum '
      + 'possible reflectance in '
      + 'dB.","type":"number"},"amplitude_minimum":{"description":"Minimum '
      + 'possible amplitude in dB.","type":"number"}},"description":"Limits of '
      + 'the measured values output by the device. The limits depend on the '
      + 'device type, measurement program and/or scan pattern.","$schema":"http'
      + '://json-schema.org/draft-04/schema#","type":"object","title":"Device '
      + 'Output Limits"}'
    );

    Example : (''
      + '{"deviation_minimum":-1,"background_radiation_minimum":0,"amplitude_ma'
      + 'ximum":100.0,"range_minimum":2.9,"mta_zone_count_maximum":7,"range_max'
      + 'imum":10000.0,"deviation_maximum":32767,"reflectance_maximum":100.0,"r'
      + 'eflectance_minimum":-100.0,"background_radiation_maximum":0,"amplitude'
      + '_minimum":0.0}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"items":{"properties":{"signed":{"type":"boolean","description":"Flag'
      + ' that is set when the original ''riegl.device'' entry in the source file'
      + ' was correctly '
      + 'signed."},"device_name":{"type":"string","description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)"},"device_type":{"type":"string","description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)"},"device_build":{"type":"string","description":"Device build'
      + ' variant"},"channel_text":{"type":"string","description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)"},"serial_number":{"type":"string","description":"Device '
      + 'serial number (e.g. S2221234)"},"channel_number":{"exclusiveMinimum":f'
      + 'alse,"type":"integer","minimum":0,"description":"Laser channel number '
      + '(not defined or 0: single channel device)"}},"required":["device_type"'
      + ',"serial_number"],"type":"object"},"description":"Details about the '
      + 'devices used to acquire the point cloud (e.g. when merging point '
      + 'clouds of different devices)","$schema":"http://json-schema.org/draft-'
      + '04/schema#","type":"array","title":"Devices Information"}'
    );

    Example : (''
      + '[{"signed":false,"device_name":"Scanner 1","device_type":"VZ-400i","de'
      + 'vice_build":"","channel_text":"","serial_number":"S2221234","channel_n'
      + 'umber":0},{"signed":true,"device_name":"Scanner 2","device_type":"VQ-1'
      + '560i-DW","device_build":"","channel_text":"","serial_number":"S2222680'
      + '","channel_number":1},{"signed":true,"device_name":"Scanner 3","device'
      + '_type":"VQ-1560i-DW","device_build":"","channel_text":"","serial_numbe'
      + 'r":"S2222680","channel_number":2}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"pre":{"description":"Dyntrig pre values","properties":'
      + '{"a":{"maxItems":2080,"description":"...","minItems":1,"items":{"type"'
      + ':"number"},"type":"array"},"nc":{"maximum":255,"description":"Number '
      + 'of entries","minimum":0,"type":"integer"}},"required":["nc","a"],"type'
      + '":"object"},"scale":{"description":"Scale in units of dB, for '
      + 'calculation of line: line number N=(amplitude-offset)/scale","type":"n'
      + 'umber"},"post":{"description":"Dyntrig post values","properties":{"a":'
      + '{"maxItems":2080,"description":"...","minItems":1,"items":{"type":"num'
      + 'ber"},"type":"array"},"nc":{"maximum":255,"description":"Number of ent'
      + 'ries","minimum":0,"type":"integer"}},"required":["nc","a"],"type":"obj'
      + 'ect"},"offset":{"description":"Offset in units of dB, for calculation '
      + 'of line","type":"number"},"tab":{"maxItems":128,"description":"...","m'
      + 'inItems":1,"items":{"type":"object","properties":{"del1":{"type":"numb'
      + 'er","description":"Length of constant post-trigger threshold elevation'
      + ' in units of m"},"thra2":{"type":"number","description":"Pre-trigger '
      + 'threshold in units of '
      + 'dB"},"thra1":{"type":"number","description":"Post-trigger threshold in'
      + ' units of dB"},"dec1":{"type":"number","description":"Decay of '
      + 'post-trigger threshold after del1 in units of '
      + 'dB/m"},"dec2":{"type":"number","description":"Rise of pre-trigger '
      + 'threshold after del2 in units of '
      + 'dB/m"},"del2":{"type":"number","description":"Length of constant '
      + 'pre-trigger threshold elevation in units of m"}},"required":["thra1","'
      + 'del1","dec1","thra2","del2","dec2"],"description":"..."},"type":"array'
      + '"}},"description":"Dyntrig","$schema":"http://json-schema.org/draft-04'
      + '/schema#","title":"Dyntrig"}'
    );

    Example : (''
      + '{"pre":{"a":[78,86,126,134,31],"nc":128},"scale":1.0,"post":{"a":[78,8'
      + '6,126,134,31],"nc":128},"offset":0.0,"tab":[{"del1":0.0,"thra2":0.0,"t'
      + 'hra1":0.0,"dec1":0.0,"dec2":0.0,"del2":0.0}]}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Echo Information","$schema":"http://json-schema.org/draft-04'
      + '/schema#","type":"object","properties":{"echo_file":{"properties":{"fi'
      + 'le_uuid":{"type":"string","description":"File''s Universally Unique '
      + 'Identifier (RFC '
      + '4122)"},"file_extension":{"type":"string","description":"Echo file '
      + 'extension, without the leading dot"}},"required":["file_extension"],"t'
      + 'ype":"object"}},"required":["echo_file"],"description":"Details about '
      + 'echo files"}'
    );

    Example : (''
      + '{"echo_file":{"file_uuid":"26a03615-67c0-4bea-8fe8-c577378fe661","file'
      + '_extension":"owp"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Exponential Decomposition","additionalProperties":false,"$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","description":"Details'
      + ' for exponential decomposition of full waveform data","patternProperti'
      + 'es":{"^[0-9]+$":{"$ref":"#/definitions/channel","description":"one '
      + 'field per channel, field name is channel index"}},"definitions":{"chan'
      + 'nel":{"properties":{"parameter":{"type":"object","properties":{"gamma"'
      + ':{"type":"array","items":{"type":"number"},"description":"decay in 1/s'
      + 'econd"},"omega":{"type":"array","items":{"type":"number"},"description'
      + '":"angular frequency in Hz"},"B":{"type":"array","items":{"type":"numb'
      + 'er"},"description":"imaginary part of amplitude factor in units of ful'
      + 'l-scale"},"A":{"type":"array","items":{"type":"number"},"description":'
      + '"real part of amplitude factor in units of full-scale"}},"required":["'
      + 'A","B","gamma","omega"],"description":"parameters of the syswave '
      + 'exponential sum"},"a_lin":{"maximum":1,"description":"relative linear '
      + 'amplitude range [0..1]","exclusiveMinimum":false,"minimum":0,"exclusiv'
      + 'eMaximum":false,"type":"number"},"delay":{"type":"number","description'
      + '":"delay calibration in '
      + 'seconds"},"scale":{"type":"number","description":"amplitude calibratio'
      + 'n"}},"required":["delay","scale","parameter"],"type":"object"}},"type"'
      + ':"object"}'
    );

    Example : (''
      + '{"1":{"parameter":{"gamma":[-1094726528.0,-769562752.0,-848000064.0],"'
      + 'omega":[352020896.0,3647927552.0,-1977987072.0],"B":[-3.9,0.0,-0.3],"A'
      + '":[0.9,0.3,-1.3]},"a_lin":0.9,"delay":3.5e-09,"scale":1.0},"0":{"param'
      + 'eter":{"gamma":[-1094726528.0,-769562752.0,-848000064.0],"omega":[3520'
      + '20896.0,3647927552.0,-1977987072.0],"B":[-3.9813032150268555,0.0862203'
      + '0913829803,-0.3152860999107361],"A":[0.9772450923919678,0.335433512926'
      + '1017,-1.312678575515747]},"a_lin":0.27,"delay":3.783458418887631e-09,"'
      + 'scale":1.0}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Gaussian Decomposition","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","properties":{"amplitude_lsb_high_powe'
      + 'r":{"items":{"type":"number"},"type":"array"},"range_offset_sec_high_p'
      + 'ower":{"items":{"type":"number"},"type":"array"},"amplitude_lsb_low_po'
      + 'wer":{"items":{"type":"number"},"type":"array"},"range_offset_sec_low_'
      + 'power":{"items":{"type":"number"},"type":"array"},"amplitude_db":{"ite'
      + 'ms":{"type":"number"},"type":"array"}},"required":["amplitude_lsb_low_'
      + 'power","amplitude_lsb_high_power","amplitude_db","range_offset_sec_low'
      + '_power","range_offset_sec_high_power"],"description":"riegl.gaussian_d'
      + 'ecomposition contains information relevant for extracting calibrated '
      + 'amplitudes and calibrated ranges from a Gaussian decomposition of full'
      + ' waveform data. This information is contained in a table with five '
      + 'columns. Two columns are to be used as input: amplitude_lsb_low_power '
      + 'and amplitude_lsb_high_power. The other three columns provide the '
      + 'outputs. Amplitude_db gives the calibrated amplitude in the optical '
      + 'regime in decibels. The range offset columns provide additive range '
      + 'offsets, given in units of seconds, for each channel."}'
    );

    Example : (''
      + '{"amplitude_lsb_high_power":[],"range_offset_sec_high_power":[],"ampli'
      + 'tude_lsb_low_power":[],"range_offset_sec_low_power":[],"amplitude_db":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"crs":{"description":"Global Coordinate Reference '
      + 'System. Please note that only 3D Cartesian Coordinate Systems are allo'
      + 'wed.","properties":{"name":{"type":"string","description":"Coordinate '
      + 'reference system '
      + 'name"},"wkt":{"type":"string","description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)"},"epsg":{"type":"integer","minimum":0,"description":"EPSG cod'
      + 'e"}},"type":"object"},"pose":{"minItems":4,"description":"Coordinate '
      + 'Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","maxItems":4,"items":{"minItems":'
      + '4,"type":"array","maxItems":4,"items":{"type":"number","description":"'
      + 'columns"},"description":"rows"},"type":"array"}},"description":"Point '
      + 'cloud georeferencing information","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","title":"Geo Tag"}'
    );

    Example : (''
      + '{"crs":{"name":"WGS84 Geocentric","wkt":"GEOCCS[\"WGS84 Geocentric\",D'
      + 'ATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY['
      + '\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\"'
      + ',0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.000'
      + '00000000000000000,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS'
      + '[\"Y\",EAST],AXIS[\"Z\",NORTH],AUTHORITY[\"EPSG\",\"4978\"]]","epsg":4'
      + '978},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"exclusiveMinimum":true,"minimum":0,"type":"number","$schema":"http:/'
      + '/json-schema.org/draft-04/schema#","description":"Geometric scale '
      + 'factor applied to point coordinates"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"body_coordinate_system_type":{"enum":["NED","ENU"],"de'
      + 'scription":"BODY coordinate frame (NED: North-East-Down, ENU: '
      + 'East-North-Up), default: NED","type":"string"},"socs_to_rocs_matrix":{'
      + '"minItems":4,"description":"Coordinate Transformation Matrix to '
      + 'transform from Scanner''s Own Coordinate System to Record Coordinate '
      + 'System. 4x4 matrix stored as two dimensional array, row major order.",'
      + '"maxItems":4,"items":{"minItems":4,"type":"array","maxItems":4,"items"'
      + ':{"type":"number","description":"columns"},"description":"rows"},"type'
      + '":"array"},"socs_to_body_matrix":{"minItems":4,"description":"Coordina'
      + 'te Transformation Matrix to transform from Scanner''s Own Coordinate '
      + 'System to Body Coordinate System. 4x4 matrix stored as two dimensional'
      + ' array, row major order.","maxItems":4,"items":{"minItems":4,"type":"a'
      + 'rray","maxItems":4,"items":{"type":"number","description":"columns"},"'
      + 'description":"rows"},"type":"array"},"trajectory_offsets":{"descriptio'
      + 'n":"Correction offsets applied to the trajectory data","properties":{"'
      + 'offset_yaw":{"description":"[deg]","type":"number"},"offset_pitch":{"d'
      + 'escription":"[deg]","type":"number"},"offset_time":{"description":"[s]'
      + '","type":"number"},"offset_roll":{"description":"[deg]","type":"number'
      + '"},"offset_north":{"description":"[m]","type":"number"},"offset_east":'
      + '{"description":"[m]","type":"number"},"version":{"description":"Meanin'
      + 'g of offset values and how to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)","type":"integer"},"offset_height":{"description":"['
      + 'm]","type":"number"}},"type":"object"},"trajectory_file":{"description'
      + '":"Trajectory data used for georeferencing of the point cloud","proper'
      + 'ties":{"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)"},"file_extension":{"type":"string","description":"Trajectory '
      + 'file extension, without the leading dot"}},"required":["file_extension'
      + '"],"type":"object"}},"description":"Parameters used for georeferencing'
      + ' of the point cloud","$schema":"http://json-schema.org/draft-04/schema'
      + '#","type":"object","title":"Georeferencing Parameters"}'
    );

    Example : (''
      + '{"body_coordinate_system_type":"NED","socs_to_body_matrix":[[-0.269827'
      + '776749716,-0.723017716139738,0.635954678449952,0.0],[0.962908599449764'
      + ',-0.20260517250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.750'
      + '8684796801,0.0],[0.0,0.0,0.0,1.0]],"trajectory_offsets":{"offset_yaw":'
      + '-0.45,"offset_pitch":0.01,"offset_time":18.007,"offset_roll":0.03,"off'
      + 'set_north":0.07,"offset_east":0.15,"version":0,"offset_height":-0.2},"'
      + 'trajectory_file":{"file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660","'
      + 'file_extension":"pofx"}}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Item Names","additionalProperties":false,"$schema":"http://j'
      + 'son-schema.org/draft-04/schema#","type":"object","patternProperties":{'
      + '"^-?[0-9]+$":{"type":"string","description":"One field per item, field'
      + ' name is item id, field value is item name"}},"description":"Map of '
      + 'item names"}'
    );

    Example : (''
      + '{"1":"Name of item with id 1","-1":"Name of item with id '
      + '-1","47":"Name of item with id 47","2":"Name of item with id 2"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Software License Keys","additionalProperties":false,"$schema'
      + '":"http://json-schema.org/draft-04/schema#","type":"object","patternPr'
      + 'operties":{"^.*$":{"type":"array","minItems":1,"items":{"type":"string'
      + '","description":"License key (example: ''46AE032A - 39882AC4 - 9EC0A184'
      + ' - 6F163D73'')"},"description":"Each field of the object represents a '
      + 'feature and holds a list of license keys, where the field name is the '
      + 'feature name."}},"description":"License keys for software features"}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography":["0FD5FF07 - 011A1255 - 9F76CACA '
      + '- 8D2ED557"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"],"Full Waveform Analysis Topography with GPU '
      + 'support":["8AB44126 - 23B92250 - 16E2689F - 34EF7E7B"],"MTA '
      + 'resolution":["468E020A - 39A922E4 - B681A184 - 673E3D72"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"zone_width":{"description":"Width of a MTA zone in met'
      + 'er.","minimum":0,"type":"number"},"modulation_depth":{"description":"D'
      + 'epth of pulse position modulation in meter.","minimum":0,"type":"numbe'
      + 'r"},"zone_count":{"maximum":255,"description":"Maximum number of MTA '
      + 'zones.","minimum":0,"type":"integer"}},"description":"Parameters for '
      + 'MTA processing","$schema":"http://json-schema.org/draft-04/schema#","t'
      + 'ype":"object","title":"MTA Settings"}'
    );

    Example : (''
      + '{"zone_width":149.896225,"modulation_depth":9.368514,"zone_count":23}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near Range Correction Table","$schema":"http://json-schema.o'
      + 'rg/draft-04/schema#","type":"object","properties":{"delta":{"type":"nu'
      + 'mber","description":"Delta between table entries [m], first entry is '
      + 'at range = 0 m"},"content":{"maxItems":2000,"type":"array","minItems":'
      + '1,"items":{"type":"number"},"description":"Correction value [m] to be '
      + 'added to the raw '
      + 'range"}},"required":["delta","content"],"description":"Lookup table '
      + 'for range correction based on raw range"}'
    );

    Example : (''
      + '{"delta":0.512,"content":[0.0]}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Noise Estimates","$schema":"http://json-schema.org/draft-04/'
      + 'schema#","type":"object","properties":{"amplitude_sigma":{"description'
      + '":"Sigma amplitude [dB]","items":{"type":"number"},"type":"array"},"ra'
      + 'nge_sigma":{"description":"Sigma range [m]","items":{"type":"number"},'
      + '"type":"array"},"amplitude":{"description":"Amplitude [dB]","items":{"'
      + 'type":"number"},"type":"array"}},"required":["amplitude","range_sigma"'
      + ',"amplitude_sigma"],"description":"Standard deviation for range and '
      + 'amplitude as a function of amplitude"}'
    );

    Example : (''
      + '{"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4'
      + '32,0.39,0.354],"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.02'
      + '4,0.021,0.018,0.016,0.014],"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.'
      + '0,8.0,9.0,10.0]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Notch Filter","$schema":"http://json-schema.org/draft-04/sch'
      + 'ema#","type":"object","properties":{"amplitude_maximum":{"description"'
      + ':"Maximum amplitude [dB]","minimum":0,"type":"number"},"range_minimum"'
      + ':{"description":"Minimum range '
      + '[m]","type":"number"},"range_maximum":{"description":"Maximum range [m'
      + ']","type":"number"}},"required":["range_minimum","range_maximum","ampl'
      + 'itude_maximum"],"description":"Notch filter parameters for window '
      + 'glass echoes"}'
    );

    Example : (''
      + '{"amplitude_maximum":18.0,"range_minimum":-0.5,"range_maximum":0.2}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pixel Information","$schema":"http://json-schema.org/draft-0'
      + '4/schema#","description":"Details about the pixels contained in the fi'
      + 'le","properties":{"size_llcs":{"$ref":"#/definitions/pixel_size","desc'
      + 'ription":"Size of pixels in a locally levelled cartesian coordinate '
      + 'system (xy). This is only used for pixels based on a map projection."}'
      + ',"size":{"$ref":"#/definitions/pixel_size","description":"Size of '
      + 'pixels in file coordinate system."}},"definitions":{"pixel_size":{"min'
      + 'Items":2,"description":"Size of '
      + 'pixels.","maxItems":2,"items":{"description":"Length of pixel edge [m]'
      + '.","minimum":0,"type":"number"},"type":"array"}},"required":["size"],"'
      + 'type":"object"}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303],"size":[0.5971642'
      + '834779395,0.5971642834779395]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Patch Matching","$schema":"http://json-schema.org/draf'
      + 't-04/schema#","description":"Details about the plane patch matching pr'
      + 'ocess","properties":{"plane_patch_file_one":{"$ref":"#/definitions/fil'
      + 'e_reference","description":"Reference to the plane patch file one"},"p'
      + 'lane_patch_file_two":{"$ref":"#/definitions/file_reference","descripti'
      + 'on":"Reference to the plane patch file '
      + 'two"}},"definitions":{"file_reference":{"description":"Reference to a '
      + 'plane patch '
      + 'file","properties":{"file_uuid":{"type":"string","description":"Plane '
      + 'patch file''s Universally Unique Identifier (RFC '
      + '4122)"},"file_path":{"type":"string","description":"Path of the plane '
      + 'patch file relative to the match file"}},"required":["file_uuid","file'
      + '_path"],"type":"object"}},"required":["plane_patch_file_one","plane_pa'
      + 'tch_file_two"],"type":"object"}'
    );

    Example : (''
      + '{"plane_patch_file_one":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b'
      + '4213","file_path":"Record009_Line001/191025_121410_Scanner_1.ptch"},"p'
      + 'lane_patch_file_two":{"file_uuid":"fa47d509-a64e-49ce-8b14-ff3130fbefa'
      + '9","file_path":"project.ptch"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"total_area":{"description":"sum of all plane patch '
      + 'areas [m\u00b2]","type":"number"},"total_horizontal_area":{"descriptio'
      + 'n":"sum of all plane patch areas projected to horizontal plane '
      + '[m\u00b2]","type":"number"}},"description":"Statistics about plane '
      + 'patches found by plane patch extractor","$schema":"http://json-schema.'
      + 'org/draft-04/schema#","type":"object","title":"Plane Patch '
      + 'Statistics"}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Plane Slope Class Info","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","properties":{"settings":{"oneOf":[{"$'
      + 'ref":"#/definitions/method-1"},{"$ref":"#/definitions/method-2"}],"des'
      + 'cription":"Classification settings, details see documentation of rdbpl'
      + 'anes","type":"object"},"classes":{"additionalProperties":false,"descri'
      + 'ption":"Class definition table","patternProperties":{"^[0-9]+$":{"type'
      + '":"string","description":"one field per class, field name is class '
      + 'number, field value is class name"}},"type":"object"}},"definitions":{'
      + '"method-1":{"description":"Classification method 1","properties":{"pla'
      + 'ne_classification_method":{"maximum":1,"description":"method ID (=1)",'
      + '"minimum":1,"type":"integer"},"maximum_inclination_angle_horizontal":{'
      + '"maximum":360.0,"description":"maximum inclination angle of horizontal'
      + ' plane patches [deg]","minimum":-360.0,"type":"number"}},"required":["'
      + 'plane_classification_method","maximum_inclination_angle_horizontal"],"'
      + 'type":"object"},"method-2":{"description":"Classification method 2","p'
      + 'roperties":{"plane_classification_method":{"maximum":2,"description":"'
      + 'method ID (=2)","minimum":2,"type":"integer"},"sloping_plane_classes_m'
      + 'inimum_angle":{"maximum":360.0,"description":"minimum inclination '
      + 'angle of sloping plane patches [deg]","minimum":-360.0,"type":"number"'
      + '},"sloping_plane_classes_maximum_angle":{"maximum":360.0,"description"'
      + ':"maximum inclination angle of sloping plane patches [deg]","minimum":'
      + '-360.0,"type":"number"}},"required":["plane_classification_method","sl'
      + 'oping_plane_classes_minimum_angle","sloping_plane_classes_maximum_angl'
      + 'e"],"type":"object"}},"required":["settings","classes"],"description":'
      + '"Settings and classes for plane slope classification"}'
    );

    Example : (''
      + '{"settings":{"plane_classification_method":2,"sloping_plane_classes_mi'
      + 'nimum_angle":10.0,"sloping_plane_classes_maximum_angle":70.0},"classes'
      + '":{"1":"horizontal, pointing up","10":"sloping, pointing down and '
      + 'east","9":"vertical, pointing west","13":"sloping, pointing down and '
      + 'west","11":"sloping, pointing down and south","7":"vertical, pointing '
      + 'south","12":"sloping, pointing down and north","14":"horizontal, '
      + 'pointing down","5":"sloping, pointing up and west","3":"sloping, '
      + 'pointing up and south","4":"sloping, pointing up and '
      + 'north","2":"sloping, pointing up and east","6":"vertical, pointing '
      + 'east","8":"vertical, pointing north"}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Point Attribute Groups","additionalProperties":false,"$schem'
      + 'a":"http://json-schema.org/draft-04/schema#","type":"object","patternP'
      + 'roperties":{"^.*$":{"type":"array","minItems":1,"items":{"type":"strin'
      + 'g","description":"Point attribute full name or name pattern (perl '
      + 'regular expression syntax)"},"description":"Each field of the object '
      + 'represents a point attribute group and holds a list of point '
      + 'attributes, where the field name is the group '
      + 'name."}},"description":"Grouping and sorting of point attributes for '
      + 'visualization purposes"}'
    );

    Example : (''
      + '{"Coordinates/Vectors":["riegl.xyz","riegl.range","riegl.theta","riegl'
      + '.phi"],"Other Attributes":["riegl.selected","riegl.visible"],"Time":["'
      + 'riegl.timestamp"],"Primary Attributes":["riegl.reflectance","riegl.amp'
      + 'litude","riegl.deviation"],"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"field_of_application":{"enum":["unknown","SLS","TLS","'
      + 'KLS","MLS","ULS","ALS","BLS","ILS"],"type":"string","description":"Fie'
      + 'ld of application"},"project":{"type":"string","description":"Project '
      + 'name"},"comments":{"type":"string","description":"Comments"}},"descrip'
      + 'tion":"Details about point cloud files","$schema":"http://json-schema.'
      + 'org/draft-04/schema#","type":"object","title":"Point Cloud '
      + 'Information"}'
    );

    Example : (''
      + '{"field_of_application":"ALS","project":"Campaign 4","comments":"Line '
      + '3"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Estimation","$schema":"http://json-schema.org/draft-04/'
      + 'schema#","type":"object","properties":{"barometric_height_amsl":{"type'
      + '":"number","description":"Altitude determined based on the atmospheric'
      + ' pressure according to the standard atmosphere laws [m]."},"position":'
      + '{"type":"object","properties":{"horizontal_accuracy":{"exclusiveMinimu'
      + 'm":true,"type":"number","minimum":0,"description":"Horizontal accuracy'
      + ' [m]"},"vertical_accuracy":{"exclusiveMinimum":true,"type":"number","m'
      + 'inimum":0,"description":"Vertical accuracy '
      + '[m]"},"coordinate_1":{"type":"number","description":"Coordinate 1 as '
      + 'defined by axis 1 of the specified CRS (e.g., X, '
      + 'Latitude)"},"coordinate_2":{"type":"number","description":"Coordinate '
      + '2 as defined by axis 2 of the specified CRS (e.g., Y, '
      + 'Longitude)"},"coordinate_3":{"type":"number","description":"Coordinate'
      + ' 3 as defined by axis 3 of the specified CRS (e.g., Z, '
      + 'Altitude)"},"crs":{"description":"Global Coordinate Reference System",'
      + '"properties":{"wkt":{"type":"string","description":"\"Well-Known '
      + 'Text\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan'
      + 'dards/wkt-crs)"},"epsg":{"type":"integer","minimum":0,"description":"E'
      + 'PSG code"}},"required":["epsg"],"type":"object"}},"required":["coordin'
      + 'ate_1","coordinate_2","coordinate_3","horizontal_accuracy","vertical_a'
      + 'ccuracy","crs"],"description":"Position coordinates and position '
      + 'accuracy values as measured by GNSS in the specified Coordinate '
      + 'Reference System (CRS)"},"orientation":{"type":"object","properties":{'
      + '"pitch":{"maximum":360,"type":"number","minimum":-360,"description":"P'
      + 'itch angle about scanner Y-axis [deg]"},"roll":{"maximum":360,"type":"'
      + 'number","minimum":-360,"description":"Roll angle about scanner X-axis '
      + '[deg]"},"yaw":{"maximum":360,"type":"number","minimum":-360,"descripti'
      + 'on":"Yaw angle about scanner Z-axis [deg]"},"pitch_accuracy":{"exclusi'
      + 'veMinimum":true,"type":"number","minimum":0,"description":"Pitch angle'
      + ' accuracy [deg]"},"roll_accuracy":{"exclusiveMinimum":true,"type":"num'
      + 'ber","minimum":0,"description":"Roll angle accuracy [deg]"},"yaw_accur'
      + 'acy":{"exclusiveMinimum":true,"type":"number","minimum":0,"description'
      + '":"Yaw angle accuracy [deg]"}},"required":["roll","pitch","yaw","roll_'
      + 'accuracy","pitch_accuracy","yaw_accuracy"],"description":"Orientation '
      + 'values and orientation accuracies, measured with IMU or inclination '
      + 'sensors."}},"required":["orientation"],"description":"Estimated '
      + 'position and orientation information as measured by GNSS, IMU or '
      + 'inclination sensors"}'
    );

    Example : (''
      + '{"barometric_height_amsl":386.7457796227932,"position":{"horizontal_ac'
      + 'curacy":0.810699999332428,"vertical_accuracy":1.3314999341964722,"coor'
      + 'dinate_1":48.655799473,"coordinate_2":15.645033406,"coordinate_3":362.'
      + '7124938964844,"crs":{"wkt":"GEOGCS[\"WGS84 / Geographic\",DATUM[\"WGS8'
      + '4\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"'
      + '7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.00000000'
      + '00000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Degree\",0.0174532925199'
      + '4329547,AUTHORITY[\"EPSG\",\"9102\"]],AXIS[\"Latitude\",NORTH],AXIS[\"'
      + 'Longitude\",EAST],AUTHORITY[\"EPSG\",\"4979\"]]","epsg":4979}},"orient'
      + 'ation":{"pitch":1.509153024827064,"roll":3.14743073066123,"yaw":101.87'
      + '293630292045,"pitch_accuracy":0.009433783936875745,"roll_accuracy":0.0'
      + '09433783936875745,"yaw_accuracy":1.0094337839368757}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pose Sensors","$schema":"http://json-schema.org/draft-04/sch'
      + 'ema#","description":"Details on position and orientation '
      + 'sensors","properties":{"accelerometer":{"description":"Accelerometer d'
      + 'etails","properties":{"unit":{"exclusiveMinimum":true,"description":"U'
      + 'nit of raw data and calibration values, 1 LSB in 9.81 m/s\u00b2","mini'
      + 'mum":0,"type":"number"},"origin":{"$ref":"#/definitions/vector","descr'
      + 'iption":"Sensor origin in SOCS [m] at frame angle = 0"},"relative_nonl'
      + 'inearity":{"$ref":"#/definitions/vector","description":"Relative '
      + 'nonlinearity, dimensionless"},"y_axis":{"$ref":"#/definitions/vector",'
      + '"description":"Sensitive Y axis of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'X axis of sensor at frame angle = 0"}},"required":["unit","x_axis","y_'
      + 'axis","z_axis","offset","origin","relative_nonlinearity"],"type":"obje'
      + 'ct"},"gyroscope":{"description":"Gyroscope details","properties":{"uni'
      + 't":{"exclusiveMinimum":true,"description":"Unit of raw data and '
      + 'calibration values, 1 LSB in rad/s","minimum":0,"type":"number"},"orig'
      + 'in":{"$ref":"#/definitions/vector","description":"Sensor origin in '
      + 'SOCS [m] at frame angle = 0"},"relative_nonlinearity":{"$ref":"#/defin'
      + 'itions/vector","description":"Relative nonlinearity, dimensionless"},"'
      + 'y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y axis'
      + ' of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'X axis of sensor at frame angle = 0"}},"required":["unit","x_axis","y_'
      + 'axis","z_axis","offset","origin","relative_nonlinearity"],"type":"obje'
      + 'ct"},"magnetic_field_sensor":{"description":"Magnetic Field Sensor det'
      + 'ails","properties":{"unit":{"exclusiveMinimum":true,"description":"Uni'
      + 't of raw data and calibration values, 1 LSB in nT","minimum":0,"type":'
      + '"number"},"fixed":{"$ref":"#/definitions/vector","description":"Distor'
      + 'tion of magnetic field caused by non-rotating scanner part"},"relative'
      + '_nonlinearity":{"$ref":"#/definitions/vector","description":"Relative '
      + 'nonlinearity, dimensionless"},"y_axis":{"$ref":"#/definitions/vector",'
      + '"description":"Sensitive Y axis of sensor at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensitive '
      + 'X axis of sensor at frame angle = 0"}},"required":["unit","x_axis","y_'
      + 'axis","z_axis","offset","fixed","relative_nonlinearity"],"type":"objec'
      + 't"}},"definitions":{"vector":{"maxItems":3,"minItems":3,"items":{"desc'
      + 'ription":"Index 0=X, 1=Y, 2=Z component","type":"number"},"type":"arra'
      + 'y"}},"required":["gyroscope","accelerometer","magnetic_field_sensor"],'
      + '"type":"object"}'
    );

    Example : (''
      + '{"accelerometer":{"unit":6.666666740784422e-05,"origin":[0.02690000087'
      + '0227814,-0.03999999910593033,-0.08950000256299973],"relative_nonlinear'
      + 'ity":[0.0,0.0,0.0],"y_axis":[-7.027288913726807,-44.12333679199219,149'
      + '52.3701171875],"offset":[-733.3636474609375,58.969032287597656,1060.25'
      + '50048828125],"z_axis":[1.639882206916809,15166.744140625,-116.99742889'
      + '404297],"x_axis":[-15008.123046875,56.956390380859375,-60.517566680908'
      + '2]},"gyroscope":{"unit":0.00014544410805683583,"origin":[0.02690000087'
      + '0227814,-0.03999999910593033,-0.08950000256299973],"relative_nonlinear'
      + 'ity":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-'
      + '39],"y_axis":[-0.440765917301178,-0.7897399663925171,119.5894775390625'
      + '],"offset":[-50.92609786987305,146.15643310546875,62.4327278137207],"z'
      + '_axis":[0.555869996547699,119.22135162353516,0.467585027217865],"x_axi'
      + 's":[-121.195556640625,0.8219714164733887,0.2313031703233719]},"magneti'
      + 'c_field_sensor":{"unit":91.74311828613281,"fixed":[-1576.010498046875,'
      + '1596.081787109375,0.0],"relative_nonlinearity":[0.0,0.0,0.0],"y_axis":'
      + '[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05],'
      + '"offset":[-23812.052734375,5606.57666015625,2493.28125],"z_axis":[0.00'
      + '041987866279669106,7.876977906562388e-05,0.011407104320824146],"x_axis'
      + '":[-0.011162743903696537,-2.315962774446234e-05,0.00016818844596855342'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Pulse Position Modulation","$schema":"http://json-schema.org'
      + '/draft-04/schema#","type":"object","properties":{"pulse_interval":{"de'
      + 'scription":"Explicit table of the pulse position modulation used for '
      + 'MTA resolution. Table gives times between successive laser pulses in s'
      + 'econds.","items":{"minimum":0,"type":"number"},"type":"array"},"code_p'
      + 'hase_mode":{"maximum":255,"description":"0: no synchronization, 1: '
      + 'toggle between 2 phases, 2: increment with phase_increment","minimum":'
      + '0,"type":"integer"},"phase_step":{"maximum":255,"description":"Step '
      + 'width in phase of modulation code from line to line","minimum":0,"type'
      + '":"integer"},"num_mod_ampl":{"maximum":255,"description":"Number of '
      + 'different modulation amplitudes (2: binary modulation)","minimum":0,"t'
      + 'ype":"integer"},"length":{"maximum":255,"description":"Length of code"'
      + ',"minimum":0,"type":"integer"}},"required":["length","num_mod_ampl","p'
      + 'ulse_interval"],"description":"Laser pulse position modulation used '
      + 'for MTA resolution"}'
    );

    Example : (''
      + '{"pulse_interval":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06'
      + ',2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82'
      + '1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e'
      + '-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2'
      + '.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218'
      + '75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0'
      + '6],"code_phase_mode":2,"phase_step":5,"num_mod_ampl":2,"length":31}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Range Statistics","$schema":"http://json-schema.org/draft-04'
      + '/schema#","type":"object","properties":{"average":{"description":"Aver'
      + 'age value","type":"number"},"minimum":{"description":"Minimum '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"},"maximum":{"description":"Maximum value","'
      + 'type":"number"}},"required":["minimum","average","maximum","std_dev"],'
      + '"description":"Statistics about target distance wrt. SOCS origin"}'
    );

    Example : (''
      + '{"average":15.49738,"minimum":0.919,"std_dev":24.349,"maximum":574.35}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Receiver Internals","$schema":"http://json-schema.org/draft-'
      + '04/schema#","description":"Receiver '
      + 'Internals","properties":{"nt":{"maximum":255,"description":"Number of '
      + 'traces","minimum":0,"type":"integer"},"sr":{"description":"Sample rate'
      + ' [Hz]","exclusiveMinimum":true,"minimum":0,"type":"number"},"a":{"maxI'
      + 'tems":256,"description":"Amplitude [dB]","minItems":1,"items":{"type":'
      + '"number"},"type":"array"},"si":{"maximum":255,"description":"Start '
      + 'index (hw_start)","minimum":0,"type":"number"},"t":{"additionalPropert'
      + 'ies":false,"patternProperties":{"^[0-9]+$":{"$ref":"#/definitions/fp",'
      + '"description":"one field per channel, field name is channel '
      + 'index"}},"type":"object"},"tbl":{"description":"various internal data"'
      + ',"minItems":1,"items":{"$ref":"#/definitions/fp_table"},"type":"array"'
      + '},"mw":{"maximum":4095,"description":"Maximum weight","exclusiveMinimu'
      + 'm":true,"minimum":0,"type":"number"},"ns":{"maximum":4095,"description'
      + '":"Number of samples","minimum":0,"type":"integer"},"ex":{"description'
      + '":"DEPRECATED, use ''riegl.exponential_decomposition'' instead","type":"'
      + 'object"}},"definitions":{"fp_table":{"properties":{"ny":{"min":1,"desc'
      + 'ription":"number of y entries","max":2048,"type":"integer"},"tv":{"max'
      + 'Items":2048,"minItems":1,"items":{"oneOf":[{"$ref":"#/definitions/fp_t'
      + 'able_row"},{"type":"number"}]},"type":"array"},"tc":{"min":0,"descript'
      + 'ion":"table data type '
      + 'code","max":255,"type":"integer"},"nx":{"min":1,"description":"number '
      + 'of x entries","max":2048,"type":"integer"},"ch":{"min":0,"description"'
      + ':"channel number","max":255,"type":"integer"}},"required":["ch","tc","'
      + 'nx","ny","tv"],"desription":"scanner internal data","type":"object"},"'
      + 'fp_table_row":{"maxItems":2048,"minItems":1,"items":{"type":"number"},'
      + '"type":"array"},"fp":{"description":"Fingerprint values","properties":'
      + '{"s":{"maxItems":256,"minItems":1,"items":{"maxItems":4096,"minItems":'
      + '1,"items":{"type":"number"},"type":"array"},"type":"array"},"w":{"maxI'
      + 'tems":256,"minItems":1,"items":{"maxItems":5,"minItems":5,"items":{"ty'
      + 'pe":"number"},"type":"array"},"type":"array"}},"required":["s","w"],"t'
      + 'ype":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"nt":128,"sr":7959997000.0,"a":[-1.55],"si":48,"t":{"1":{"s":[[1.23,4'
      + '.56],[7.89,0.12]],"w":[[78,86,126,134,31],[78,86,126,134,31]]},"0":{"s'
      + '":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134,31],[78,86,126,134,31]'
      + ']}},"tbl":[{"ny":2,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],"tc":1,"nx'
      + '":5,"ch":0}],"mw":31,"ns":400}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Reflectance Calculation Table","$schema":"http://json-schema'
      + '.org/draft-04/schema#","type":"object","properties":{"delta":{"type":"'
      + 'number","description":"Delta between table entries [m], first entry is'
      + ' at range = 0 m"},"content":{"maxItems":2000,"type":"array","minItems"'
      + ':1,"items":{"type":"number"},"description":"Correction value [dB] to '
      + 'be added to the '
      + 'amplitude"}},"required":["delta","content"],"description":"Lookup '
      + 'table for reflectance calculation based on amplitude and range"}'
    );

    Example : (''
      + '{"delta":0.150918,"content":[-33.01]}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Near-range reflectance correction","$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#","type":"object","properties":{"line_angles_'
      + 'deg":{"description":"Angle [deg]","items":{"type":"number"},"type":"ar'
      + 'ray"},"ranges_m":{"description":"Range [m]","items":{"type":"number"},'
      + '"type":"array"},"reflectance_correction_db":{"description":"Near range'
      + ' reflectance correction in dB as a function of range over angle","item'
      + 's":{"type":"array","items":{"type":"number","description":"columns '
      + '(each value corresponds to an angle)"},"description":"rows (each array'
      + ' corresponds to a range)"},"type":"array"}},"required":["ranges_m","li'
      + 'ne_angles_deg","reflectance_correction_db"],"description":"Range-depen'
      + 'dent and scan-angle-dependent correction of reflectance reading"}'
    );

    Example : (''
      + '{"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],"ranges_m'
      + '":[0.0,1.0,2.0,3.0],"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,'
      + '0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.'
      + '8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,'
      + '0.1,0.05,0.01]]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"rectangular":{"type":"object","properties":{"phi_incre'
      + 'ment":{"maximum":90.0,"type":"number","minimum":0.0,"description":"Inc'
      + 'rement of phi angle in SOCS [deg]"},"theta_start":{"maximum":180.0,"ty'
      + 'pe":"number","minimum":0.0,"description":"Start theta angle in SOCS [d'
      + 'eg]"},"theta_stop":{"maximum":180.0,"type":"number","minimum":0.0,"des'
      + 'cription":"Stop theta angle in SOCS [deg]"},"theta_increment":{"maximu'
      + 'm":90.0,"type":"number","minimum":0.0,"description":"Increment of '
      + 'theta angle in SOCS [deg]"},"phi_start":{"maximum":360.0,"type":"numbe'
      + 'r","minimum":0.0,"description":"Start phi angle in SOCS [deg]"},"progr'
      + 'am":{"$ref":"#/definitions/program"},"phi_stop":{"maximum":720.0,"type'
      + '":"number","minimum":0.0,"description":"Stop phi angle in SOCS [deg]"}'
      + '},"required":["phi_start","phi_stop","phi_increment","theta_start","th'
      + 'eta_stop","theta_increment"],"description":"Rectangular Field Of View '
      + 'Scan Pattern"},"line":{"type":"object","properties":{"program":{"$ref"'
      + ':"#/definitions/program"},"stop":{"maximum":720.0,"type":"number","min'
      + 'imum":0.0,"description":"Stop angle in SOCS [deg]"},"increment":{"maxi'
      + 'mum":90.0,"type":"number","minimum":0.0,"description":"Increment of '
      + 'angle in SOCS [deg]"},"start":{"maximum":360.0,"type":"number","minimu'
      + 'm":0.0,"description":"Start angle in SOCS '
      + '[deg]"}},"required":["start","stop","increment"],"description":"Line '
      + 'Scan Pattern"},"segments":{"type":"object","properties":{"program":{"$'
      + 'ref":"#/definitions/program"},"list":{"items":{"type":"object","proper'
      + 'ties":{"stop":{"maximum":720.0,"type":"number","minimum":0.0,"descript'
      + 'ion":"Stop angle in SOCS [deg]"},"increment":{"maximum":90.0,"type":"n'
      + 'umber","minimum":0.0,"description":"Increment of angle in SOCS [deg]"}'
      + ',"start":{"maximum":360.0,"type":"number","minimum":0.0,"description":'
      + '"Start angle in SOCS '
      + '[deg]"}},"required":["start","stop","increment"],"description":"Line '
      + 'Scan Segment"},"type":"array"}},"required":["list"],"description":"Seg'
      + 'mented Line Scan Pattern"}},"description":"Scan pattern description","'
      + '$schema":"http://json-schema.org/draft-04/schema#","definitions":{"pro'
      + 'gram":{"type":"object","properties":{"name":{"type":"string","descript'
      + 'ion":"Name of measurement program"},"laser_prr":{"exclusiveMinimum":fa'
      + 'lse,"type":"number","minimum":0,"description":"Laser Pulse Repetition '
      + 'Rate [Hz]"}},"required":["name"],"description":"Measurement '
      + 'program"}},"title":"Scan Pattern"}'
    );

    Example : (''
      + '{"rectangular":{"phi_increment":0.04,"theta_start":30.0,"theta_stop":1'
      + '30.0,"theta_increment":0.04,"phi_start":45.0,"program":{"name":"High '
      + 'Speed","laser_prr":100000.0},"phi_stop":270.0}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"shot_file":{"properties":{"file_uuid":{"type":"string"'
      + ',"description":"File''s Universally Unique Identifier (RFC '
      + '4122)"},"file_extension":{"type":"string","description":"Shot file '
      + 'extension, without the leading dot"}},"required":["file_extension"],"t'
      + 'ype":"object"}},"description":"Details about laser shot files","$schem'
      + 'a":"http://json-schema.org/draft-04/schema#","type":"object","title":"'
      + 'Shot Information"}'
    );

    Example : (''
      + '{"shot_file":{"file_uuid":"26a00815-67c0-4bff-8fe8-c577378fe663","file'
      + '_extension":"sodx"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Stored filters","$schema":"http://json-schema.org/draft-04/s'
      + 'chema#","type":"object","properties":{"filters":{"type":"array","items'
      + '":{"type":"object","properties":{"description":{"type":"string","descr'
      + 'iption":"A brief description of the filter (e.g. for display in a '
      + 'tooltip)"},"filter":{"type":"string","description":"The RDB filter '
      + 'string to apply (e.g. when reading points or index), details see '
      + 'documentation of function '
      + 'select()"},"activated":{"type":"boolean","description":"Apply (''true'')'
      + ' or ignore (''false'') this '
      + 'filter"},"title":{"type":"string","description":"A short filter title '
      + '(e.g. for display in a selection list)"}},"required":["activated","tit'
      + 'le","description","filter"],"description":"Point filter '
      + 'definition"},"description":"List of point '
      + 'filters"},"activated":{"type":"boolean","description":"Apply (''true'') '
      + 'or ignore (''false'') all '
      + 'filters"}},"required":["activated","filters"],"description":"Point '
      + 'filters applied in addition to the application-defined filters"}'
    );

    Example : (''
      + '{"filters":[{"description":"Ignore points with uncertain MTA zone '
      + 'assignment","filter":"riegl.mta_uncertain_point == '
      + '0","activated":false,"title":"Ignore uncertain points from MTA '
      + 'resolution"},{"description":"Ignore points with an echo signal '
      + 'amplitude below the dynamic '
      + 'trigger","filter":"riegl.dyntrig_uncertain_point == '
      + '0","activated":false,"title":"Ignore points below dynamic trigger '
      + 'level"},{"description":"Ignore points that are outside the outer AABB '
      + 'in BOCS","filter":"riegl.point_outside_aabb_bocs == '
      + '0","activated":false,"title":"Ignore points outside outer '
      + 'AABB"},{"description":"Ignore points that are inside the inner AABB in'
      + ' BOCS","filter":"riegl.point_inside_aabb_bocs == '
      + '0","activated":false,"title":"Ignore points inside inner '
      + 'AABB"}],"activated":true}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"System Description","$schema":"http://json-schema.org/draft-'
      + '04/schema#","type":"object","properties":{"$class":{"enum":["Document"'
      + '],"type":"string","description":"Object class '
      + 'name"},"system":{"type":"object","description":"The actual system '
      + 'description, details see documentation of RIEGL System '
      + 'Description"},"version":{"type":"string","description":"Document '
      + 'format version"},"author":{"type":"string","description":"Name of the '
      + 'author that created the '
      + 'document"},"timestamp":{"type":"string","description":"Date and time '
      + 'of creation (e.g. 2019-06-19T13:32:10+02:00)"}},"required":["$class","'
      + 'version","author","timestamp","system"],"description":"Details of '
      + 'major system components like lidar sensors, cameras and navigation '
      + 'devices"}'
    );

    Example : (''
      + '{"$class":"Document","system":{"details":"see documentation of RIEGL '
      + 'System Description"},"version":"1.2.1","author":"RIEGL LMS GmbH, '
      + 'Austria","timestamp":"2022-09-30T11:56:26+00:00"}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Temperature Calculation Table","$schema":"http://json-schema'
      + '.org/draft-04/schema#","description":"Conversion of background '
      + 'radiation raw values to temperatures in \u00b0C","properties":{"InGaAs'
      + '_Si_Difference":{"$ref":"#/definitions/conversion_table","description"'
      + ':"Conversion table for InGaAs - Si difference"},"Si":{"$ref":"#/defini'
      + 'tions/conversion_table","description":"Conversion table for Si channel'
      + '"},"InGaAs":{"$ref":"#/definitions/conversion_table","description":"Co'
      + 'nversion table for InGaAs channel"}},"definitions":{"conversion_table"'
      + ':{"properties":{"value":{"description":"LSB [1]","items":{"type":"numb'
      + 'er"},"type":"array"},"temperature":{"description":"Temperature [\u00b0'
      + 'C]","items":{"type":"number"},"type":"array"}},"required":["value","te'
      + 'mperature"],"type":"object"}},"type":"object"}'
    );

    Example : (''
      + '{"InGaAs_Si_Difference":{"value":[1000.0,1100.090029602954,1200.044251'
      + '83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13'
      + '27555162209,1700.0869777520065,1800.0411999877924],"temperature":[1749'
      + '.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109'
      + '2,1622.3944822534868]},"Si":{"value":[0.0,64.00097659230323,128.001953'
      + '1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005'
      + '8595538194,448.0068361461226,512.0078127384259],"temperature":[546.300'
      + '048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60'
      + '4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0'
      + '002936624203]},"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846'
      + '065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595'
      + '538194,448.0068361461226,512.0078127384259],"temperature":[307.2219672'
      + '2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213'
      + '7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3'
      + '157023200148]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Time Base","$schema":"http://json-schema.org/draft-04/schema'
      + '#","type":"object","properties":{"source":{"enum":["unknown","RTC","GN'
      + 'SS"],"type":"string","description":"Timestamp source"},"system":{"enum'
      + '":["unknown","UTC","GPS"],"type":"string","description":"Time system '
      + '(time standard)"},"epoch":{"type":"string","description":"Date and '
      + 'time of timestamp ''0'' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:0'
      + '0+01:00)."}},"required":["epoch","source"],"description":"Base of '
      + 'timestamps (epoch)"}'
    );

    Example : (''
      + '{"source":"GNSS","system":"UTC","epoch":"2015-10-27T00:00:00+00:00"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Trajectory Information","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","properties":{"location":{"type":"stri'
      + 'ng","description":"Project location, e.g. '
      + 'city/state/country"},"project":{"type":"string","description":"Project'
      + ' name"},"navigation_frame":{"enum":["unknown","NED","ENU"],"type":"str'
      + 'ing","description":"Navigation frame (NED: North-East-Down, ENU: '
      + 'East-North-Up)"},"software":{"type":"string","description":"Software '
      + 'that calculated the trajectory (this may be the same or different '
      + 'software than the one that created the '
      + 'file)"},"settings":{"type":"string","description":"Settings used to '
      + 'calculate the trajectory (descriptive '
      + 'text)"},"device":{"type":"string","description":"Navigation device, '
      + 'e.g. name/type/serial"},"field_of_application":{"enum":["unknown","SLS'
      + '","TLS","KLS","MLS","ULS","ALS","BLS","ILS"],"type":"string","descript'
      + 'ion":"Field of '
      + 'application"},"company":{"type":"string","description":"Company name"}'
      + ',"time_interval":{"type":"object","properties":{"average":{"type":"num'
      + 'ber","description":"Average time interval '
      + '[s]"},"minimum":{"type":"number","description":"Minimum time interval '
      + '[s]"},"std_dev":{"type":"number","description":"Standard deviation of '
      + 'intervals [s]"},"maximum":{"type":"number","description":"Maximum time'
      + ' interval [s]"}},"required":["minimum","average","maximum","std_dev"],'
      + '"description":"Time interval statistics"}},"required":["time_interval"'
      + ',"navigation_frame"],"description":"Details about position+orientation'
      + ' files"}'
    );

    Example : (''
      + '{"location":"Horn","project":"Campaign '
      + '3","navigation_frame":"NED","software":"Navigation Software '
      + 'XYZ","settings":"default","device":"IMU Model 12/1, Serial# '
      + '12345","field_of_application":"MLS","company":"RIEGL LMS","time_interv'
      + 'al":{"average":0.00500053,"minimum":0.00500032,"std_dev":5.51e-07,"max'
      + 'imum":0.005004883}}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"TTIP Configuration","$schema":"http://json-schema.org/draft-'
      + '04/schema#","type":"object","properties":{"dmi_min_time":{"type":"inte'
      + 'ger","minimum":0,"description":"dmi, minimum time interval between '
      + 'trigger events [0.1 msec]"},"dmi_max_time":{"type":"integer","minimum"'
      + ':0,"description":"dmi, maximum time interval between trigger events '
      + '[0.1 msec]"},"num_channel":{"type":"integer","minimum":0,"description"'
      + ':"number of input/output '
      + 'channels"},"channel":{"type":"integer","minimum":0,"description":"ID '
      + 'of input/output channel"},"ext_delay":{"type":"integer","minimum":0,"d'
      + 'escription":"external trigger, time delay [0.1 msec]"},"out_interval":'
      + '{"type":"integer","minimum":0,"description":"output pulse interval '
      + '[0.1 msec]"},"in_max_delay":{"type":"integer","minimum":0,"description'
      + '":"maximum delay to output pulse before fake event is generated [0.1 '
      + 'msec], zero indicates that no fake events are generated"},"in_max_dura'
      + 'tion":{"type":"integer","minimum":0,"description":"stops measurement '
      + 'of pulse duration of input signal [0.1 '
      + 'msec]"},"input_usage":{"type":"integer","minimum":0,"description":"0 '
      + '.. deactivated, 1 .. just detecting and timestamping"},"out_delay":{"t'
      + 'ype":"integer","minimum":0,"description":"output pulse initial delay '
      + 'after start [0.1 '
      + 'msec]"},"out_polarity":{"type":"integer","minimum":0,"description":"0 '
      + '.. positive edge, 1 .. negative '
      + 'edge"},"ext_signal":{"type":"integer","minimum":0,"description":"0 .. '
      + 'use input signal, 1 .. use output signal of '
      + 'channel"},"dmi_dist_per_tick":{"type":"number","description":"dmi, '
      + 'distance per tick, just informative '
      + '[m]"},"output_usage":{"type":"integer","minimum":0,"description":"0 ..'
      + ' no output, 1 .. output derived from internal clock, 2 .. output '
      + 'derived from dmi, 3 .. output derived from external signal, 4 .. '
      + 'output static low, 5 .. output static high"},"out_duration":{"type":"i'
      + 'nteger","minimum":0,"description":"output pulse duration [0.1 msec]"},'
      + '"ext_bitmask":{"type":"integer","minimum":0,"description":"defines '
      + 'which of the internal pulse generators are to be started"},"ext_channe'
      + 'l":{"type":"integer","minimum":0,"description":"ID of channel used as '
      + 'external trigger input, 32 indicates none"},"in_min_duration":{"type":'
      + '"integer","minimum":0,"description":"input signals with smaller pulse '
      + 'durations are ignored [0.1 msec]"},"out_num_pulses":{"type":"integer",'
      + '"minimum":0,"description":"number of output pulses to be generated, 0 '
      + '.. infinite"},"ext_subdivider":{"type":"integer","minimum":0,"descript'
      + 'ion":"reduces the frequency, default 1"},"ttip_version":{"type":"integ'
      + 'er","minimum":0,"description":"following main.sub.ss.sss"},"in_polarit'
      + 'y":{"type":"integer","minimum":0,"description":"0 .. positive edge, 1 '
      + '.. negative edge"},"dmi_incr":{"type":"integer","description":"dmi, '
      + 'increment in '
      + 'ticks"},"output_descr":{"type":"string","description":"descriptive '
      + 'string"},"input_descr":{"type":"string","description":"descriptive str'
      + 'ing"}},"required":["ttip_version","num_channel","ext_channel","ext_sig'
      + 'nal","ext_delay","ext_subdivider","ext_bitmask","dmi_incr","dmi_min_ti'
      + 'me","dmi_max_time","dmi_dist_per_tick","channel","output_descr","input'
      + '_descr","output_usage","input_usage","out_polarity","out_duration","ou'
      + 't_interval","out_delay","out_num_pulses","in_polarity","in_min_duratio'
      + 'n","in_max_duration","in_max_delay"],"description":"Trigger-Timestampi'
      + 'ng-Unit/IP configuration"}'
    );

    Example : (''
      + '{"dmi_min_time":0,"dmi_max_time":0,"num_channel":9,"channel":0,"ext_de'
      + 'lay":0,"out_interval":10000,"in_max_delay":9990,"in_max_duration":1000'
      + '0,"input_usage":1,"out_delay":0,"out_polarity":0,"ext_signal":0,"dmi_d'
      + 'ist_per_tick":0.0,"output_usage":1,"out_duration":300,"ext_bitmask":0,'
      + '"ext_channel":32,"in_min_duration":0,"out_num_pulses":1,"ext_subdivide'
      + 'r":1,"ttip_version":1,"in_polarity":0,"dmi_incr":0,"output_descr":"Por'
      + 't 1 - Trigger","input_descr":"Port 1 - Exposure"}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"vertex_file":{"properties":{"file_uuid":{"type":"strin'
      + 'g","description":"File''s Universally Unique Identifier (RFC '
      + '4122)"},"file_extension":{"type":"string","description":"Vertex file '
      + 'extension, without the leading dot"}},"required":["file_extension"],"t'
      + 'ype":"object"}},"description":"Details about vertex file","$schema":"h'
      + 'ttp://json-schema.org/draft-04/schema#","type":"object","title":"Verte'
      + 'x Information"}'
    );

    Example : (''
      + '{"vertex_file":{"file_uuid":"51534d95-d71f-4f36-ae1a-3e63a21fd1c7","fi'
      + 'le_extension":"vtx"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Voxel Information","$schema":"http://json-schema.org/draft-0'
      + '4/schema#","oneOf":[{"additionalProperties":false,"properties":{"voxel'
      + '_type":{"$ref":"#/definitions/voxel_type"},"shape_thresholds":{"$ref":'
      + '"#/definitions/shape_thresholds"},"voxel_origin":{"$ref":"#/definition'
      + 's/voxel_origin_enum"},"size":{"oneOf":[{"$ref":"#/definitions/voxel_si'
      + 'ze"},{"$ref":"#/definitions/voxel_size_cubic"}],"description":"Size of'
      + ' voxels in file coordinate system."}},"required":["size","voxel_origin'
      + '","voxel_type"]},{"additionalProperties":false,"properties":{"size_llc'
      + 's":{"$ref":"#/definitions/voxel_size","description":"Size of voxels in'
      + ' a locally levelled cartesian coordinate system (xyz). This is only '
      + 'used for voxels based on a map projection."},"size":{"$ref":"#/definit'
      + 'ions/voxel_size","description":"Size of voxels in file coordinate syst'
      + 'em."},"voxel_type":{"$ref":"#/definitions/voxel_type"},"shape_threshol'
      + 'ds":{"$ref":"#/definitions/shape_thresholds"},"voxel_origin":{"oneOf":'
      + '[{"$ref":"#/definitions/voxel_origin_enum"},{"$ref":"#/definitions/vox'
      + 'el_origin_point","description":"The base point of the voxel grid. Used'
      + ' together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute'
      + ' actual point coordinates."}]},"reference_point":{"maxItems":2,"type":'
      + '"array","minItems":2,"items":{"maximum":180,"minimum":-180,"type":"num'
      + 'ber"},"description":"Point in WGS84 geodetic decimal degree '
      + '(EPSG:4326) that was used to compute the projection distortion '
      + 'parameters. The coefficient order is latitude, longitude. Only voxels '
      + 'with corresponding geo_tag, voxel_size and reference_point can be '
      + 'reliably processed together. This entry is available for voxel files '
      + 'in projected CRS only."}},"required":["reference_point","size_llcs","s'
      + 'ize","voxel_origin","voxel_type"]}],"type":"object","definitions":{"vo'
      + 'xel_origin_enum":{"enum":["center","corner"],"default":"corner","descr'
      + 'iption":"Defines whether the voxel''s center or a corner is placed on '
      + 'CRS origin <tt>(0/0/0)</tt>."},"edge_length":{"exclusiveMinimum":true,'
      + '"minimum":0,"type":"number","description":"Length of voxel edge [m]."}'
      + ',"voxel_size":{"maxItems":3,"type":"array","minItems":3,"items":{"$ref'
      + '":"#/definitions/edge_length"},"description":"Size of voxels."},"voxel'
      + '_type":{"enum":["center","centroid","index"],"default":"centroid","des'
      + 'cription":"Whether a point in a voxel represents its center or its '
      + 'centroid. If type is <tt>index</tt> there is no point but only an '
      + 'integer voxel index."},"shape_thresholds":{"type":"object","properties'
      + '":{"line":{"exclusiveMinimum":true,"minimum":1,"type":"number","descri'
      + 'ption":"If the biggest eigenvalue is bigger than the median eigenvalue'
      + ' * line_threshold, the voxel is considered a '
      + 'line."},"plane":{"maximum":1,"description":"If the smallest eigenvalue'
      + ' is smaller than the median eigenvalue * plane_threshold, the voxel is'
      + ' considered a plane.","exclusiveMinimum":true,"minimum":0,"exclusiveMa'
      + 'ximum":true,"type":"number"}},"required":["plane","line"],"description'
      + '":"Thresholds used to compute the voxel''s shape_id value."},"voxel_siz'
      + 'e_cubic":{"$ref":"#/definitions/edge_length","type":"number"},"voxel_o'
      + 'rigin_point":{"maxItems":3,"type":"array","minItems":3,"items":{"type"'
      + ':"number"},"description":"Origin point for all voxel indices in voxel '
      + 'CRS."}},"description":"Details about the voxels contained in the '
      + 'file"}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303,0.5143705304787237'
      + '],"size":[0.5971642834779395,0.5971642834779395,0.5143705304787237],"v'
      + 'oxel_type":"centroid","shape_thresholds":{"line":6,"plane":0.16},"voxe'
      + 'l_origin":"corner","reference_point":[48,16]}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Waveform Averaging Settings","$schema":"http://json-schema.o'
      + 'rg/draft-04/schema#","type":"object","properties":{"num_shots":{"descr'
      + 'iption":"Number of consecutive shots to be used for averaging.","minim'
      + 'um":1,"type":"integer"},"trim":{"maximum":0.5,"description":"Percentag'
      + 'e for robust averaging.","minimum":0,"default":0,"type":"number"},"mta'
      + '_zone":{"description":"Fixed MTA zone for averaging.","minimum":1,"typ'
      + 'e":"integer"}},"required":["num_shots","mta_zone"],"description":"Sett'
      + 'ings for waveform averaging"}'
    );

    Example : (''
      + '{"num_shots":7,"trim":0.05,"mta_zone":1}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'title":"Waveform Information","properties":{"sample_block_file":{"prop'
      + 'erties":{"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)"},"file_extension":{"type":"string","description":"Sample block '
      + 'file extension, without the leading dot"}},"required":["file_extension'
      + '"],"type":"object"},"range_offset_m":{"type":"number","description":"C'
      + 'alibrated device specific range offset for waveform analysis by system'
      + ' response fitting in meters."},"sample_data_files":{"items":{"properti'
      + 'es":{"sample_bits":{"maximum":32,"type":"integer","exclusiveMinimum":f'
      + 'alse,"minimum":0,"exclusiveMaximum":false,"description":"Bitwidth of '
      + 'samples (e.g. 10 bit, 12 bit)"},"sample_interval":{"exclusiveMinimum":'
      + 'false,"type":"number","minimum":0,"description":"Sampling interval in '
      + 'seconds"},"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC 4122)"},"delta_st":{"type":"number"'
      + ',"description":"reserved"},"file_extension":{"type":"string","descript'
      + 'ion":"Sample data file extension, without the leading dot"},"channel":'
      + '{"maximum":255,"type":"integer","exclusiveMinimum":false,"minimum":0,"'
      + 'exclusiveMaximum":false,"description":"Sample block channel number '
      + '(255 = invalid)"},"laser_wavelength":{"exclusiveMinimum":false,"type":'
      + '"number","minimum":0,"description":"Laser wavelength in meters (0 = '
      + 'unknown)"},"channel_name":{"type":"string","description":"Sample block'
      + ' channel name"}},"required":["channel","channel_name","sample_interval'
      + '","sample_bits","laser_wavelength","delta_st","file_extension"],"type"'
      + ':"object"},"type":"array"},"range_offset_waveform_samples_m":{"type":"'
      + 'number","description":"Calibrated device specific range offset for '
      + 'waveform samples in meters."}},"required":["sample_block_file","sample'
      + '_data_files"],"description":"Details about waveform files"}'
    );

    Example : (''
      + '{"sample_data_files":[{"sample_bits":12,"sample_interval":1.00503e-09,'
      + '"laser_wavelength":0,"delta_st":0,"file_uuid":"da084413-e3e8-4655-a122'
      + '-071de8490d8e","channel":0,"channel_name":"high_power","file_extension'
      + '":"sp0"},{"sample_bits":12,"sample_interval":1.00503e-09,"laser_wavele'
      + 'ngth":0,"delta_st":0,"file_uuid":"93585b5e-5ea9-43a1-947b-e7ba3be642d2'
      + '","channel":1,"channel_name":"low_power","file_extension":"sp1"},{"sam'
      + 'ple_bits":12,"sample_interval":1.00503e-09,"laser_wavelength":0,"delta'
      + '_st":0,"file_uuid":"9d2298c4-1036-464f-b5cb-1cf8e517f3a0","channel":5,'
      + '"channel_name":"wwf","file_extension":"sp5"}],"range_offset_m":3.1415,'
      + '"range_offset_waveform_samples_m ":7.283,"sample_block_file":{"file_uu'
      + 'id":"93a03615-66c0-4bea-8ff8-c577378fe660","file_extension":"sbx"}}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"items":{"properties":{"enabled":{"type":"boolean","description":"Wav'
      + 'eform output '
      + 'enabled"},"pass_rng_less":{"type":"number","description":"Threshold '
      + 'for range less than '
      + '[m]"},"pass_ampl_less":{"type":"number","description":"Threshold for '
      + 'amplitude less than '
      + '[dB]"},"sbl_name":{"type":"string","description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf"},"pass_dev_greater":{"type":"integer","description":"Threshold '
      + 'for deviation greater than '
      + '[1]"},"logic_expression":{"type":"string","description":"Logic '
      + 'expression of smart waveforms '
      + 'filter"},"pass_ampl_greater":{"type":"number","description":"Threshold'
      + ' for amplitude greater than '
      + '[dB]"},"pass_rng_greater":{"type":"number","description":"Threshold '
      + 'for range greater than '
      + '[m]"},"pass_dev_less":{"type":"integer","description":"Threshold for '
      + 'deviation less than '
      + '[1]"},"channel_idx_mask":{"type":"integer","description":"Bit mask for'
      + ' channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ..."},"smart_enabled":{"type":"boolean","description":"Smart '
      + 'waveform output enabled"}},"required":["sbl_name","enabled","channel_i'
      + 'dx_mask"],"type":"object"},"description":"Scanner settings for '
      + 'waveform output","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'type":"array","title":"Waveform Settings"}'
    );

    Example : (''
      + '[{"enabled":true,"pass_rng_less":13.11,"pass_ampl_less":5.0,"sbl_name"'
      + ':"wfm","pass_ampl_greater":1.0,"pass_rng_greater":9.27,"channel_idx_ma'
      + 'sk":11,"smart_enabled":true},{"enabled":false,"sbl_name":"wwf","channe'
      + 'l_idx_mask":32}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Analysis","$schema":"http://json-schema.org/draft-04/'
      + 'schema#","type":"object","properties":{"result":{"properties":{"amplit'
      + 'ude_offset":{"description":"[dB]","items":{"type":"number"},"type":"ar'
      + 'ray"},"range_mean":{"description":"[m]","items":{"type":"number"},"typ'
      + 'e":"array"},"timestamp":{"description":"[s]","items":{"type":"number"}'
      + ',"type":"array"},"amplitude_sigma":{"description":"[dB]","items":{"typ'
      + 'e":"number"},"type":"array"},"angle":{"description":"[deg]","items":{"'
      + 'type":"number"},"type":"array"},"range_sigma":{"description":"[m]","it'
      + 'ems":{"type":"number"},"type":"array"},"amplitude_mean":{"description"'
      + ':"[dB]","items":{"type":"number"},"type":"array"}},"required":["angle"'
      + ',"range_mean","range_sigma","amplitude_mean","amplitude_sigma","amplit'
      + 'ude_offset"],"type":"object"},"filter":{"properties":{"angle":{"descri'
      + 'ption":"[deg]","items":{"type":"number"},"type":"array"},"amplitude_ma'
      + 'x":{"description":"[dB]","items":{"type":"number"},"type":"array"},"ra'
      + 'nge_min":{"description":"[m]","items":{"type":"number"},"type":"array"'
      + '},"range_max":{"description":"[m]","items":{"type":"number"},"type":"a'
      + 'rray"}},"required":["angle","range_min","range_max","amplitude_max"],"'
      + 'type":"object"},"settings":{"properties":{"amplitude":{"properties":{"'
      + 'additive_value":{"type":"number"},"sigma_factor":{"type":"number"}},"r'
      + 'equired":["sigma_factor","additive_value"],"type":"object"},"range":{"'
      + 'properties":{"additive_value":{"type":"number"},"sigma_factor":{"type"'
      + ':"number"}},"required":["sigma_factor","additive_value"],"type":"objec'
      + 't"}},"required":["range","amplitude"],"type":"object"}},"required":["r'
      + 'esult","filter","settings"],"description":"Window analysis data '
      + 'estimated from scandata and resulting filter parameters"}'
    );

    Example : (''
      + '{"result":{"amplitude_offset":[1.9,1.9],"range_mean":[0.1105621,0.1079'
      + '564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.10515'
      + '23,0.1058445,0.1031261],"timestamp":[408.4441,411.4443],"amplitude_sig'
      + 'ma":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.437'
      + '3984,0.4472798,0.4346001,0.4345487,0.4540681],"angle":[14.9,15.0,15.1,'
      + '15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_sigma":[0.01869652,0.0'
      + '2151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0.02225'
      + '589,0.02229977,0.01899122,0.02009433],"amplitude_mean":[5.347396,5.263'
      + '155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.0'
      + '02441,4.982]},"filter":{"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15'
      + '.6,15.7,15.8,15.9],"amplitude_max":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,'
      + '7.85,7.83,7.8,7.78],"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.'
      + '218,-0.219,-0.221,-0.223,-0.225,-0.227],"range_max":[0.424,0.425,0.426'
      + ',0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432]},"settings":{"amplitu'
      + 'de":{"additive_value":1.0,"sigma_factor":4},"range":{"additive_value":'
      + '0.1,"sigma_factor":8}}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Window Echo Correction","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","type":"object","properties":{"range":{"description":"'
      + 'Range axis of correction '
      + 'table","properties":{"maximum":{"maximum":2.0,"description":"Maximum '
      + 'range in m","minimum":-2.0,"type":"number"},"minimum":{"maximum":2.0,"'
      + 'description":"Minimum range in '
      + 'm","minimum":-2.0,"type":"number"},"entries":{"description":"Number of'
      + ' range entries","minimum":1,"type":"integer"}},"required":["minimum","'
      + 'maximum","entries"],"type":"object"},"amplitude":{"description":"Ampli'
      + 'tude axis of correction '
      + 'table","properties":{"maximum":{"description":"Maximum amplitude in '
      + 'dB","minimum":0.0,"type":"number"},"minimum":{"description":"Minimum '
      + 'amplitude in '
      + 'dB","minimum":0.0,"type":"number"},"entries":{"description":"Number of'
      + ' amplitude entries","minimum":1,"type":"integer"}},"required":["minimu'
      + 'm","maximum","entries"],"type":"object"},"slices":{"items":{"descripti'
      + 'on":"Window echo correction parameter '
      + 'slice","properties":{"table":{"description":"Correction table '
      + '(dimension defined by the ''amplitude'' and ''range'' '
      + 'objects)","minItems":1,"items":{"description":"Table row (= amplitude '
      + 'axis)","minItems":1,"items":{"maxItems":3,"description":"Table column '
      + '(= range '
      + 'axis)","minItems":3,"items":{"type":"number","description":"Table cell'
      + ' (item 0: amplitude in dB, 1: range in m, 2: flags)"},"type":"array"},'
      + '"type":"array"},"type":"array"},"amplitude":{"description":"Window '
      + 'echo amplitude of slice in dB","type":"number"}},"required":["amplitud'
      + 'e","table"],"type":"object"},"type":"array"}},"required":["amplitude",'
      + '"range","slices"],"description":"Correction parameters for window '
      + 'glass echoes"}'
    );

    Example : (''
      + '{"range":{"maximum":1.5060822940732335,"minimum":-1.5060822940732335,"'
      + 'entries":128},"amplitude":{"maximum":20,"minimum":2,"entries":128},"sl'
      + 'ices":[{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":1.5'
      + '},{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":2.0}]}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
